@@ -27,8 +27,10 @@ const our $BUILD_STATUS_TEXT => {
     -1 => 'error',
     0  => 'queued',
     1  => 'queued',
+    2  => 'building',
     3  => 'building',
     10 => 'success',
+    11 => 'queued',
 };
 
 sub BUILDARGS ( $self, $args = undef ) {
@@ -615,12 +617,12 @@ sub trigger_autobuild_by_tag_name ( $self, $repo_id, $autobuild_tag_name, $cb =
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 79, 188, 322, 332,   | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
-## |      | 348, 376, 380, 415,  |                                                                                                                |
-## |      | 487, 506, 510, 554,  |                                                                                                                |
-## |      | 567                  |                                                                                                                |
+## |    3 | 81, 190, 324, 334,   | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
+## |      | 350, 378, 382, 417,  |                                                                                                                |
+## |      | 489, 508, 512, 556,  |                                                                                                                |
+## |      | 569                  |                                                                                                                |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    1 | 166                  | CodeLayout::RequireTrailingCommas - List declaration without trailing comma                                    |
+## |    1 | 168                  | CodeLayout::RequireTrailingCommas - List declaration without trailing comma                                    |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
